@@ -2,7 +2,7 @@
 #import <random.h>
 
 /*
-static char Id="$Id: AgentModelSwarm.m,v 1.3 1998/02/28 08:47:18 mgd Exp $";
+static char Id="$Id: AgentModelSwarm.m,v 1.4 2000/02/27 18:21:43 mgd Exp $";
 */
 
 @implementation AgentModelSwarm
@@ -202,13 +202,15 @@ static char Id="$Id: AgentModelSwarm.m,v 1.3 1998/02/28 08:47:18 mgd Exp $";
 // in any customization of the model, so we defer most object creation
 // to later. (In this example, this method does nothing at all and could
 // just be inherited. But it's here to show you a place to customize.)
--createEnd {
+- createEnd
+{
   return [super createEnd];
 }
 
 // Now it's time to build the model objects. We use various parameters
 // inside ourselves to choose how to create things.
--buildObjects {
+- buildObjects
+{
   int i;
   id randG;
   id uRand;
@@ -217,29 +219,29 @@ static char Id="$Id: AgentModelSwarm.m,v 1.3 1998/02/28 08:47:18 mgd Exp $";
   int k, l;
   
   // for the generator
-  randG = [PMMLCG1 createBegin: [self getZone]];
+  randG = [PMMLCG1gen createBegin: [self getZone]];
   [randG setStateFromSeed: seedValueLocAgt];
   randG = [randG createEnd]; 
   // for the distribution
-  uRand = [UniformInteger createBegin: [self getZone]];
+  uRand = [UniformIntegerDist createBegin: [self getZone]];
   [uRand setGenerator: randG];
   uRand = [uRand createEnd];
 
-  //randG = [[PMMLCG1 alloc] initSeed: seedValueLocAgt];	  // seeds from clock
-  //uRand = [[[Uniform alloc] init] setGenerator: randG];
+  //randG = [[PMMLCG1gen alloc] initSeed: seedValueLocAgt];	  // seeds from clock
+  //uRand = [[[UniformIntegerDist alloc] init] setGenerator: randG];
 
 
   // for the generator
-  randGOrient = [PMMLCG1 createBegin: [self getZone]];
+  randGOrient = [PMMLCG1gen createBegin: [self getZone]];
   [randGOrient setStateFromSeed: 5000];
   randGOrient = [randGOrient createEnd]; 
   // for the distribution
-  uRandOrient = [UniformInteger createBegin: [self getZone]];
+  uRandOrient = [UniformIntegerDist createBegin: [self getZone]];
   [uRandOrient setGenerator: randGOrient];
   uRandOrient = [uRandOrient createEnd];
 
-  //randGOrient = [[PMMLCG1 alloc] initSeed: 5000];	  // seeds from clock
-  //uRandOrient = [[[Uniform alloc] init] setGenerator: randGOrient];
+  //randGOrient = [[PMMLCG1gen alloc] initSeed: 5000];	  // seeds from clock
+  //uRandOrient = [[[UniformIntegerDist alloc] init] setGenerator: randGOrient];
 
   // allow our parent class to build anything.
   [super buildObjects];
@@ -425,6 +427,19 @@ static char Id="$Id: AgentModelSwarm.m,v 1.3 1998/02/28 08:47:18 mgd Exp $";
 
 /*
 $Log: AgentModelSwarm.m,v $
+Revision 1.4  2000/02/27 18:21:43  mgd
+* Makefile (SWARMHOME, APPVERSION): Update for 2.1.
+
+* AgentProbaCamera.m ([AgentProbaCamera -setSeedCarrying:],
+[AgentProbaCamera -setSeedCarrying:],
+[AgentProbaCamera -setSeedCCW:]): Update PMMLCG1 to PMLLCGgen1
+and UniformInteger to UniformIntegerDist.
+
+* AgentModelSwarm.m ([AgentModelSwarm -buildObjects],
+[AgentModelSwarm -buildObjects]): Likewise.
+
+* WorldObject.m ([WorldObject -InitSetObjects:]): Likewise.
+
 Revision 1.3  1998/02/28 08:47:18  mgd
 * AgentProbaCamera.m: Include random.h instead of simtools.h.
 
