@@ -1,7 +1,7 @@
 // AgentObserverSwarm.m
 
 /*
-static char Id="$Id: AgentObserverSwarm.m,v 1.4 1999/01/16 22:51:05 alex Exp $";
+static char Id="$Id: AgentObserverSwarm.m,v 1.6 2000/01/13 16:39:33 mgd Exp $";
 */
 
 #import "AgentObserverSwarm.h"
@@ -267,7 +267,7 @@ static unsigned numStackToShow = 10;
     BiggestStackGrapher = [BiggestStackGrapher createEnd];
 
     useHisto = [Histogram createBegin: globalZone];
-    [useHisto setNumBins: numStackToShow];
+    [useHisto setBinCount: numStackToShow];
     useHisto = [useHisto createEnd];
 //      [useHisto setNumPoints: numStackToShow
 //  	    Labels: descr
@@ -389,7 +389,7 @@ static unsigned numStackToShow = 10;
 
       Input_parameters = fopen([self getFileName], "a");
       // be careful with this: works only for some experiments: there is a need to customize it!
-      fprintf(Input_parameters, "%d\t%d\t%d\t%d\n", [agentModelSwarm getNumAgents], [agentModelSwarm getSeedValueObj], [[[agentModelSwarm getAgentList] first] getSeedDispl], [agentModelSwarm getNumIterations]);
+      fprintf(Input_parameters, "%d\t%d\t%d\t%d\n", [agentModelSwarm getNumAgents], [agentModelSwarm getSeedValueObj], [[[agentModelSwarm getAgentList] getFirst] getSeedDispl], [agentModelSwarm getNumIterations]);
       fclose(Input_parameters);
       [getTopLevelActivity() terminate]; // to leave automatically
     }
@@ -412,7 +412,7 @@ static unsigned numStackToShow = 10;
 
       Input_parameters = fopen([self getFileName], "a");
       // be careful with this: works only for some experiments: there is a need to customize it!
-      fprintf(Input_parameters, "%d\t%d\%d\t%d\n", [agentModelSwarm getNumAgents], [agentModelSwarm getSeedValueObj], [[[agentModelSwarm getAgentList] first] getSeedDispl], [agentModelSwarm getNumIterations]);
+      fprintf(Input_parameters, "%d\t%d\%d\t%d\n", [agentModelSwarm getNumAgents], [agentModelSwarm getSeedValueObj], [[[agentModelSwarm getAgentList] getFirst] getSeedDispl], [agentModelSwarm getNumIterations]);
       fclose(Input_parameters);
       [getTopLevelActivity() terminate]; // to leave automatically
     }
@@ -536,6 +536,17 @@ static unsigned numStackToShow = 10;
 
 /*
 $Log: AgentObserverSwarm.m,v $
+Revision 1.6  2000/01/13 16:39:33  mgd
+* AgentObserverSwarm.m ([AgentObserverSwarm -checkToStop]): Use getFirst instead of first.
+
+Revision 1.5  1999/08/25 21:15:07  mgd
+* main.m: Include simtools.h.
+
+* Makefile (APPVERSION, BUGADDRESS): Add.
+
+* AgentObserverSwarm.m ([AgentObserverSwarm -buildObjects]): Use
+setBinCount: instead of setNumBins:.
+
 Revision 1.4  1999/01/16 22:51:05  alex
 * AgentObserverSwarm.m ([AgentObserverSwarm -buildObjects]): Initialize the
   Histogram instance `useHisto' according to the latest version of protocol
