@@ -2,7 +2,7 @@
 
 
 /*
-static char Id="$Id: AgentProbaCamera.m,v 1.5 1998/04/24 21:19:13 mgd Exp $";
+static char Id="$Id: AgentProbaCamera.m,v 1.7 2000/02/27 18:22:57 mgd Exp $";
 */
 
 #import "AgentProbaCamera.h"
@@ -134,46 +134,47 @@ static char Id="$Id: AgentProbaCamera.m,v 1.5 1998/04/24 21:19:13 mgd Exp $";
   return CWCCWRotation;
 }
 
--setSeedDispl: (int)value
+- setSeedDispl: (int)value
 {
   seedValueAgt=value;
-  //randGAgt = [[PMMLCG1 alloc] initSeed: seedValueAgt];	  // seeds from clock
-  //uRandAgt = [[[Uniform alloc] init] setGenerator: randGAgt];
+  //randGAgt = [[PMMLCG1gen alloc] initSeed: seedValueAgt];	  // seeds from clock
+  //uRandAgt = [[[UniformIntegerDist alloc] init] setGenerator: randGAgt];
   //for the generator 
-  randGAgt = [PMMLCG1 createBegin: [self getZone]];
+  randGAgt = [PMMLCG1gen createBegin: [self getZone]];
   [randGAgt setStateFromSeed: seedValueAgt];
   randGAgt = [randGAgt createEnd];
   // for the distribution
-  uRandAgt = [UniformInteger createBegin: [self getZone]];
+  uRandAgt = [UniformIntegerDist createBegin: [self getZone]];
   [uRandAgt setGenerator: randGAgt];
   uRandAgt = [uRandAgt createEnd];
   return self;
 }
--setSeedCarrying: (int)value
+
+- setSeedCarrying: (int)value
 {
   seedValueAgtOb = value;
-  //randGAgtOb = [[PMMLCG1 alloc] initSeed: seedValueAgtOb];	  // seeds from clock
-  //uRandAgtOb = [[[Uniform alloc] init] setGenerator: randGAgtOb];
+  //randGAgtOb = [[PMMLCG1gen alloc] initSeed: seedValueAgtOb];	  // seeds from clock
+  //uRandAgtOb = [[[UniformIntegerDist alloc] init] setGenerator: randGAgtOb];
   //for the generator 
-  randGAgtOb = [PMMLCG1 createBegin: [self getZone]];
+  randGAgtOb = [PMMLCG1gen createBegin: [self getZone]];
   [randGAgtOb setStateFromSeed: seedValueAgtOb];
   randGAgtOb = [randGAgtOb createEnd];
   // for the distribution
-  uRandAgtOb = [UniformInteger createBegin: [self getZone]];
+  uRandAgtOb = [UniformIntegerDist createBegin: [self getZone]];
   [uRandAgtOb setGenerator: randGAgtOb];
   uRandAgtOb = [uRandAgtOb createEnd];
   return self;
 }
 
--setSeedCCW: (int)value
+- setSeedCCW: (int)value
 {
   seedValueAgtCCW = value;
   //for the generator 
-  randGAgtCCW = [PMMLCG1 createBegin: [self getZone]];
+  randGAgtCCW = [PMMLCG1gen createBegin: [self getZone]];
   [randGAgtCCW setStateFromSeed: seedValueAgtCCW];
   randGAgtCCW = [randGAgtCCW createEnd];
   // for the distribution
-  uRandAgtCCW = [UniformInteger createBegin: [self getZone]];
+  uRandAgtCCW = [UniformIntegerDist createBegin: [self getZone]];
   [uRandAgtCCW setGenerator: randGAgtCCW];
   uRandAgtCCW = [uRandAgtCCW createEnd];
   return self;
@@ -1587,6 +1588,9 @@ static char Id="$Id: AgentProbaCamera.m,v 1.5 1998/04/24 21:19:13 mgd Exp $";
 
 /*
 $Log: AgentProbaCamera.m,v $
+Revision 1.7  2000/02/27 18:22:57  mgd
+*** empty log message ***
+
 Revision 1.5  1998/04/24 21:19:13  mgd
 Revert WorldObject protocol things.
 
